@@ -8,11 +8,27 @@ zeroInflationdists<-sort(c('gamma','weibull','exp','lnorm','beta'))
 oneInflationdists<-sort(c('beta'))
 integerdists<-sort(c('bern','pois'))
 splineList<-c("bs","ns","bSpline","mSpline","cSpline","iSpline")
-meansList<-c("numeric","integer","logical","Date","POSIXlt","POSIXct","difftime")
+meansList<-c("matrix","numeric","integer","logical","Date","POSIXlt","POSIXct","difftime")
 meansListNoTime<-c("numeric","integer","logical")
 plotArgs <- c("cex","cex.main","cex.lab","cex.axis","cex.legend","lwd","asp","legend.pos")
 fitMethods<-c("nlm","Nelder-Mead","SANN")
 
+# startup message
+#' @importFrom utils packageVersion available.packages
+print.momentuHMM.version <- function()
+{ version <- utils::packageVersion("momentuHMM")
+  hello <- paste("Loading momentuHMM ",version,sep="")
+  curVersion <- tryCatch(suppressWarnings(utils::available.packages(repos = "http://cran.us.r-project.org")["momentuHMM","Version"]),error=function(e) e)
+  packageStartupMessage(hello)
+  if(!inherits(curVersion,"error")){
+    if(version<curVersion) warning("  A newer version (",curVersion,") is available from CRAN")
+  }
+}
+
+.onAttach <- function(...) { 
+  print.momentuHMM.version()
+}
+
 # this function maintains backwards compatibility with momentuHMM versions <1.1.2 (formulaDelta) and <1.4.0 (workBounds)
 delta_bc <- function(m){
   
