@@ -5,7 +5,7 @@ library(sp)
 load(url("https://raw.github.com/bmcclintock/momentuHMM/master/vignettes/turtleData.RData"))
 
 nSims <- 100 # number of imputatons
-retryFits <- 30 # number attempt to re-fit based on random perturbation
+retryFits <- 250 # number attempt to re-fit based on random perturbation
 ncores <- 7 # number of CPU cores
 
 inits<-list(a=c(coordinates(turtleData)[1,1],0,
@@ -21,7 +21,7 @@ constr=list(lower=c(rep(log(1000*0.534),3),rep(log(1000*0.301),3),rep(-Inf,2)),#
 
 predTimes <- seq(as.POSIXlt("2012-11-20 02:00:00 UTC",tz="UTC"),as.POSIXlt("2012-12-19 04:00:00 UTC",tz="UTC"),"2 hours")
 
-crwOut<-crawlWrap(turtleData,ncores=1,retryFits=retryFits,Time.name="time",
+crwOut<-crawlWrap(turtleData,retryFits=retryFits,Time.name="time",
                   err.model=err.model,initial.state=inits,
                   theta=c(7.730711, 8.216563, 8.505832, 7.103412, 7.245771, 7.935648, 5.371427, -10.677923),fixPar = fixPar, constr=constr,
                   predTime=predTimes) 
@@ -51,11 +51,6 @@ Par0<-list(step=c(9.132130, 9.200282, 0, 8.579123, 8.640819),
 turtleFits<-MIfitHMM(miTurtleData$miData,ncores=ncores,
                      nbStates=nbStates,dist=dist,Par0=Par0,DM=DM,estAngleMean=estAngleMean,circularAngleMean=circularAngleMean,retryFits=retryFits)
 
-#for pooling remove any imputations where angle coeff strayed along boundary, i.e., keep those with -15 < 'mean_2:d' < 15
-ind<-which(dunif(unlist(lapply(turtleFits$HMMfits,function(x) x$CIbeta$angle$est[1])),-15,15)>0)
-turtleFits$HMMfits<-turtleFits$HMMfits[seq(1,nSims)[ind]]
-turtleFits$miSum<-MIpool(turtleFits$HMMfits,ncores=ncores)
-
 plot(turtleFits,plotCI=TRUE,covs=data.frame(angle_osc=1),ask=FALSE)
 
 save.image("turtleExample.RData")
